@@ -1,11 +1,11 @@
-from typing import List, Optional
+from typing import Optional
 
 from ..helpers import to_int
 from .songs import *
 
 
-def parse_playlist_header(response: Dict) -> Dict[str, Any]:
-    playlist: Dict[str, Any] = {}
+def parse_playlist_header(response: dict) -> dict[str, Any]:
+    playlist: dict[str, Any] = {}
     editable_header = nav(response, [*HEADER, *EDITABLE_PLAYLIST_DETAIL_HEADER], True)
     playlist["owned"] = editable_header is not None
     playlist["privacy"] = "PUBLIC"
@@ -53,7 +53,7 @@ def parse_playlist_header(response: Dict) -> Dict[str, Any]:
     return playlist
 
 
-def parse_playlist_items(results, menu_entries: Optional[List[List]] = None, is_album=False):
+def parse_playlist_items(results, menu_entries: Optional[list[list]] = None, is_album=False):
     songs = []
     for result in results:
         if MRLIR not in result:
@@ -67,8 +67,8 @@ def parse_playlist_items(results, menu_entries: Optional[List[List]] = None, is_
 
 
 def parse_playlist_item(
-    data: Dict, menu_entries: Optional[List[List]] = None, is_album=False
-) -> Optional[Dict]:
+    data: dict, menu_entries: Optional[list[list]] = None, is_album=False
+) -> Optional[dict]:
     videoId = setVideoId = None
     like = None
     feedback_tokens = None
@@ -101,11 +101,13 @@ def parse_playlist_item(
     if "musicItemRendererDisplayPolicy" in data:
         isAvailable = data["musicItemRendererDisplayPolicy"] != "MUSIC_ITEM_RENDERER_DISPLAY_POLICY_GREY_OUT"
 
-    # For unavailable items indexes are preset,
-    # because meaning of the flex column cannot be found using navigationEndpoint
-    title_index = 0 if isAvailable is False else None
-    artist_index = 1 if isAvailable is False else None
-    album_index = 2 if isAvailable is False else None
+    # For unavailable items and for album track lists indexes are preset,
+    # because meaning of the flex column cannot be reliably found using navigationEndpoint
+    use_preset_columns = True if isAvailable is False or is_album is True else None
+
+    title_index = 0 if use_preset_columns else None
+    artist_index = 1 if use_preset_columns else None
+    album_index = 2 if use_preset_columns else None
     user_channel_indexes = []
     unrecognized_index = None
 
@@ -114,7 +116,8 @@ def parse_playlist_item(
         navigation_endpoint = nav(flex_column_item, [*TEXT_RUN, "navigationEndpoint"], True)
 
         if not navigation_endpoint:
-            unrecognized_index = index if unrecognized_index is None else unrecognized_index
+            if nav(flex_column_item, TEXT_RUN_TEXT, True) is not None:
+                unrecognized_index = index if unrecognized_index is None else unrecognized_index
             continue
 
         if "watchEndpoint" in navigation_endpoint:
@@ -137,6 +140,9 @@ def parse_playlist_item(
                 album_index = index
             elif page_type == "MUSIC_PAGE_TYPE_USER_CHANNEL":
                 user_channel_indexes.append(index)
+            # Non music videos, for example: podcast episodes
+            elif page_type == "MUSIC_PAGE_TYPE_NON_MUSIC_AUDIO_TRACK_PAGE":
+                title_index = index
 
     # Extra check for rare songs, where artist is non-clickable and does not have navigationEndpoint
     if artist_index is None and unrecognized_index is not None:
