@@ -2,6 +2,9 @@ from dataclasses import dataclass
 
 from .songs import *
 
+PROGRESS_RENDERER = ["musicPlaybackProgressRenderer"]
+DURATION_TEXT = ["durationText", "runs", 1, "text"]
+
 
 @dataclass
 class DescriptionElement:
@@ -22,7 +25,7 @@ class Timestamp(DescriptionElement):
 
 
 @dataclass
-class Description(List[DescriptionElement]):
+class Description(list[DescriptionElement]):
     def __init__(self, *args, **kwargs):
         super().__init__(args[0])
 
@@ -31,14 +34,14 @@ class Description(List[DescriptionElement]):
         return "".join(str(element) for element in self)
 
     @classmethod
-    def from_runs(cls, description_runs: List[Dict]) -> "Description":
+    def from_runs(cls, description_runs: list[dict]) -> "Description":
         """parse the description runs into a usable format
 
         :param description_runs: the original description runs
 
         :return: List of text (str), timestamp (int) and link values (Link object)
         """
-        elements: List[DescriptionElement] = []
+        elements: list[DescriptionElement] = []
         for run in description_runs:
             navigationEndpoint = nav(run, ["navigationEndpoint"], True)
             if navigationEndpoint:
@@ -58,7 +61,7 @@ class Description(List[DescriptionElement]):
         return cls(elements)
 
 
-def parse_base_header(header: Dict) -> Dict:
+def parse_base_header(header: dict) -> dict:
     """parse common left hand side (header) items of an episode or podcast page"""
     strapline = nav(header, ["straplineTextOne"])
     return {
@@ -70,7 +73,7 @@ def parse_base_header(header: Dict) -> Dict:
     }
 
 
-def parse_podcast_header(header: Dict) -> Dict:
+def parse_podcast_header(header: dict) -> dict:
     metadata = parse_base_header(header)
     metadata["description"] = nav(header, ["description", *DESCRIPTION_SHELF, *DESCRIPTION], True)
     metadata["saved"] = nav(header, ["buttons", 1, *TOGGLED_BUTTON])
@@ -78,13 +81,13 @@ def parse_podcast_header(header: Dict) -> Dict:
     return metadata
 
 
-def parse_episode_header(header: Dict) -> Dict:
+def parse_episode_header(header: dict) -> dict:
     metadata = parse_base_header(header)
     metadata["date"] = nav(header, [*SUBTITLE2])
     metadata["duration"] = nav(header, [*SUBTITLE3], True)
     if not metadata["duration"]:  # progress started
-        progress_renderer = nav(header, ["progress", "musicPlaybackProgressRenderer"])
-        metadata["duration"] = nav(progress_renderer, ["durationText", "runs", 1, "text"], True)
+        progress_renderer = nav(header, ["progress", *PROGRESS_RENDERER])
+        metadata["duration"] = nav(progress_renderer, DURATION_TEXT, True)
         metadata["progressPercentage"] = nav(progress_renderer, ["playbackProgressPercentage"])
     metadata["saved"] = nav(header, ["buttons", 0, *TOGGLED_BUTTON], True) or False
 
@@ -100,12 +103,8 @@ def parse_episode_header(header: Dict) -> Dict:
 def parse_episode(data):
     """Parses a single episode under "Episodes" on a channel page or on a podcast page"""
     thumbnails = nav(data, THUMBNAILS)
-    date = None
-    if len(nav(data, SUBTITLE_RUNS)) == 1:
-        duration = nav(data, SUBTITLE)
-    else:
-        date = nav(data, SUBTITLE)
-        duration = nav(data, SUBTITLE2, True)
+    date = nav(data, SUBTITLE, True)
+    duration = nav(data, ["playbackProgress", *PROGRESS_RENDERER, *DURATION_TEXT], True)
     title = nav(data, TITLE_TEXT)
     description = nav(data, DESCRIPTION, True)
     videoId = nav(data, ["onTap", *WATCH_VIDEO_ID], True)
